@@ -42,11 +42,17 @@
 #include "units.h"
 #include "compression.h"
 #include "byteorder.h"
+#include "print.h"
 
 #include "modules/rebuffer.h"
 
+#ifdef DEBUG
+#define CHNK(X) X
+#define DEBG(X) X
+#else
 #define CHNK(X)
 #define DEBG(X)
+#endif
 
 extern _PCMInfo _af_default_signed_integer_pcm_mappings[];
 extern _PCMInfo _af_default_unsigned_integer_pcm_mappings[];
@@ -98,12 +104,12 @@ AFframecount _AFpull (_AFmoduleinst *i, AFframecount nframes2pull)
 	_AFmoduleinst *src = i->u.pull.source;
 
 	i->inc->nframes = nframes2pull;
-	CHNK(printf("%s pulling %d frames from %s\n",
+	CHNK(printf("%s pulling %" AF_FRAMECOUNT_PRINT_FMT " frames from %s\n",
 		i->mod->name, i->inc->nframes, src->mod->name));
 	(*src->mod->run_pull)(src);
 	CHNK(_af_print_chunk(i->inc));
 
-	CHNK(printf("%s received %d frames from %s\n",
+	CHNK(printf("%s received %" AF_FRAMECOUNT_PRINT_FMT " frames from %s\n",
 		i->mod->name, i->inc->nframes, src->mod->name));
 	return i->inc->nframes;
 }
@@ -124,7 +130,7 @@ void _AFpush (_AFmoduleinst *i, AFframecount nframes2push)
 {
 	_AFmoduleinst *snk = i->u.push.sink;
 	i->outc->nframes = nframes2push;
-	CHNK(printf("%s pushing %d frames into %s\n",
+	CHNK(printf("%s pushing %" AF_FRAMECOUNT_PRINT_FMT " frames into %s\n",
 		i->mod->name, i->outc->nframes, snk->mod->name));
 	CHNK(_af_print_chunk(i->outc));
 	(*(snk->mod->run_push))(snk);
@@ -143,7 +149,8 @@ void _AFpushat (_AFmoduleinst *i, AFframecount startframe, bool stretchint,
 		(_af_format_frame_size_uncompressed(&i->outc->f,stretchint) * startframe);
 
 	i->outc->nframes = nframes2push;
-	CHNK(printf("%s pushing %d frames into %s with OFFSET %d frames\n",
+	CHNK(printf("%s pushing %" AF_FRAMECOUNT_PRINT_FMT " frames into %s "
+		"with OFFSET %" AF_FILEOFFSET_PRINT_FMT " frames\n",
 		i->mod->name, i->outc->nframes, snk->mod->name, startframe));
 	CHNK(_af_print_chunk(i->outc));
 	(*(snk->mod->run_push))(snk);
@@ -279,33 +286,59 @@ MODULESWAP(swap8, real_char8,
 */
 
 /* convert 0xaabbcc to 0xssaabbcc */
-MODULE(real_char3_to_schar3, f /* NOTUSED */,
-	real_char3, schar3,
+#ifdef WORDS_BIGENDIAN
+MODULE(real_char3_to_schar3, f /* NOTUSED */, real_char3, schar3,
 	{
 		char3u u;
 		u.real_char3_high.c3 = ip[i];
 		u.real_char3_high.pad = 0;
 		op[i] = u.schar3.i >> 8;
 	})
+#else
+MODULE(real_char3_to_schar3, f /* NOTUSED */, real_char3, schar3,
+	{
+		char3u u;
+		u.real_char3_low.c3 = ip[i];
+		u.real_char3_low.pad = 0;
+		op[i] = u.schar3.i >> 8;
+	})
+#endif
 
 /* convert 0xaabbcc to 0x00aabbcc */
-MODULE(real_char3_to_uchar3, f /*NOTUSED*/,
-	real_char3, uchar3,
+#ifdef WORDS_BIGENDIAN
+MODULE(real_char3_to_uchar3, f /* NOTUSED */, real_char3, uchar3,
 	{
 		char3u u;
 		u.real_char3_high.c3 = ip[i];
 		u.real_char3_high.pad = 0;
 		op[i] = u.uchar3.i >> 8;
 	})
+#else
+MODULE(real_char3_to_uchar3, f /* NOTUSED */, real_char3, uchar3,
+	{
+		char3u u;
+		u.real_char3_low.c3 = ip[i];
+		u.real_char3_low.pad = 0;
+		op[i] = u.uchar3.i >> 8;
+	})
+#endif
 
 /* convert 0x??aabbcc to 0xaabbcc */
-MODULE(char3_to_real_char3, f /*NOTUSED*/,
-	uchar3, real_char3,
+#ifdef WORDS_BIGENDIAN
+MODULE(char3_to_real_char3, f /* NOTUSED */, uchar3, real_char3,
 	{
 		char3u u;
 		u.uchar3.i = ip[i];
 		op[i] = u.real_char3_low.c3;
 	})
+#else
+MODULE(char3_to_real_char3, f /* NOTUSED */, uchar3, real_char3,
+	{
+		char3u u;
+		u.uchar3.i = ip[i];
+		op[i] = u.real_char3_high.c3;
+	})
+#endif
 
 /*
 	float <--> double ; CASTS
@@ -1382,6 +1415,7 @@ format_code get_format_code (_AudioFormat *fmt)
 		}
 	}
 
+	/* NOTREACHED */
 	assert(0);
 	return -1;
 }
@@ -2592,7 +2626,6 @@ status _AFsetupmodules (AFfilehandle h, _Track *track)
 	for (i=track->ms.nmodules-1; i >= 0; i--)
 	{
 		_AFmoduleinst *inst = &track->ms.module[i];
-		inst->dump = AF_TRUE;
 	}
 
 	{
