@@ -55,39 +55,33 @@ AUpvlist afQuery (int querytype, int arg1, int arg2, int arg3, int arg4)
 	{
 		case AF_QUERYTYPE_INST:
 			return _afQueryInstrument(arg1, arg2, arg3, arg4);
-			break;
 		case AF_QUERYTYPE_INSTPARAM:
 			return _afQueryInstrumentParameter(arg1, arg2, arg3, arg4);
-			break;
 		case AF_QUERYTYPE_LOOP:
 			return _afQueryLoop(arg1, arg2, arg3, arg4);
-			break;
 		case AF_QUERYTYPE_FILEFMT:
 			return _afQueryFileFormat(arg1, arg2, arg3, arg4);
-			break;
 		case AF_QUERYTYPE_COMPRESSION:
 			/* FIXME: This selector is not implemented. */
 			return AU_NULL_PVLIST;
-			break;
 		case AF_QUERYTYPE_COMPRESSIONPARAM:
 			/* FIXME: This selector is not implemented. */
 			return AU_NULL_PVLIST;
-			break;
 		case AF_QUERYTYPE_MISC:
 			/* FIXME: This selector is not implemented. */
 			return AU_NULL_PVLIST;
-			break;
 		case AF_QUERYTYPE_MARK:
 			return _afQueryMarker(arg1, arg2, arg3, arg4);
-			break;
 		default:
 			_af_error(AF_BAD_QUERYTYPE, "bad query type");
 			return AU_NULL_PVLIST;
 	}
 
+	/* NOTREACHED */
 	return AU_NULL_PVLIST;
 }
 
+/* ARGSUSED3 */
 AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 {
 	switch (arg1)
@@ -101,6 +95,7 @@ AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 					count++;
 			return _af_pv_long(count);
 		}
+		/* NOTREACHED */
 		break;
 
 		case AF_QUERY_IDS:
@@ -124,6 +119,7 @@ AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 
 			return _af_pv_pointer(buffer);
 		}
+		/* NOTREACHED */
 		break;
 
 		/* The following select on arg2. */
@@ -131,25 +127,21 @@ AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 			if (arg2 < 0 || arg2 >= _AF_NUM_UNITS)
 				return AU_NULL_PVLIST;
 			return _af_pv_pointer(_af_units[arg2].label);
-			break;
 
 		case AF_QUERY_NAME:
 			if (arg2 < 0 || arg2 >= _AF_NUM_UNITS)
 				return AU_NULL_PVLIST;
 			return _af_pv_pointer(_af_units[arg2].name);
-			break;
 
 		case AF_QUERY_DESC:
 			if (arg2 < 0 || arg2 >= _AF_NUM_UNITS)
 				return AU_NULL_PVLIST;
 			return _af_pv_pointer(_af_units[arg2].description);
-			break;
 
 		case AF_QUERY_IMPLEMENTED:
 			if (arg2 < 0 || arg2 >= _AF_NUM_UNITS)
 				return AU_NULL_PVLIST;
 			return _af_pv_long(_af_units[arg2].implemented);
-			break;
 
 		/* The following select on arg3. */
 		case AF_QUERY_SAMPLE_FORMATS:
@@ -159,11 +151,10 @@ AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 			{
 				case AF_QUERY_DEFAULT:
 					return _af_pv_long(_af_units[arg3].defaultSampleFormat);
-					break;
 				default:
 					return AU_NULL_PVLIST;
-					break;
 			}
+			/* NOTREACHED */
 			break;
 
 		case AF_QUERY_SAMPLE_SIZES:
@@ -174,10 +165,10 @@ AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 			{
 				case AF_QUERY_DEFAULT:
 					return _af_pv_long(_af_units[arg3].defaultSampleWidth);
-					break;
 				default:
 					break;
 			}
+			/* NOTREACHED */
 			break;
 
 		case AF_QUERY_COMPRESSION_TYPES:
@@ -197,7 +188,6 @@ AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 				case AF_QUERY_VALUE_COUNT:
 					count = _af_units[arg3].compressionTypeCount;
 					return _af_pv_long(count);
-					break;
 
 				case AF_QUERY_VALUES:
 					count = _af_units[arg3].compressionTypeCount;
@@ -214,7 +204,6 @@ AUpvlist _afQueryFileFormat (int arg1, int arg2, int arg3, int arg4)
 					}
 
 					return _af_pv_pointer(buffer);
-					break;
 			}
 		}
 		break;
@@ -274,6 +263,7 @@ void *afQueryPointer (int querytype, int arg1, int arg2, int arg3, int arg4)
 	return value;
 }
 
+/* ARGSUSED3 */
 AUpvlist _afQueryInstrumentParameter (int arg1, int arg2, int arg3, int arg4)
 {
 	switch (arg1)
@@ -283,13 +273,11 @@ AUpvlist _afQueryInstrumentParameter (int arg1, int arg2, int arg3, int arg4)
 			if (arg2 < 0 || arg2 >= _AF_NUM_UNITS)
 				return AU_NULL_PVLIST;
 			return _af_pv_long(_af_units[arg2].instrumentParameterCount != 0);
-			break;
 
 		case AF_QUERY_ID_COUNT:
 			if (arg2 < 0 || arg2 >= _AF_NUM_UNITS)
 				return AU_NULL_PVLIST;
 			return _af_pv_long(_af_units[arg2].instrumentParameterCount);
-			break;
 
 		case AF_QUERY_IDS:
 		{
@@ -308,6 +296,7 @@ AUpvlist _afQueryInstrumentParameter (int arg1, int arg2, int arg3, int arg4)
 				buffer[i] = _af_units[arg2].instrumentParameters[i].id;
 			return _af_pv_pointer(buffer);
 		}
+		/* NOTREACHED */
 		break;
 
 		/*
@@ -364,6 +353,7 @@ AUpvlist _afQueryInstrumentParameter (int arg1, int arg2, int arg3, int arg4)
 	return AU_NULL_PVLIST;
 }
 
+/* ARGSUSED2 */
 AUpvlist _afQueryLoop (int arg1, int arg2, int arg3, int arg4)
 {
 	if (arg2 < 0 || arg2 >= _AF_NUM_UNITS)
@@ -382,6 +372,7 @@ AUpvlist _afQueryLoop (int arg1, int arg2, int arg3, int arg4)
 	return AU_NULL_PVLIST;
 }
 
+/* ARGSUSED2 */
 AUpvlist _afQueryInstrument (int arg1, int arg2, int arg3, int arg4)
 {
 	switch (arg1)
@@ -403,31 +394,32 @@ AUpvlist _afQueryInstrument (int arg1, int arg2, int arg3, int arg4)
 	return AU_NULL_PVLIST;
 }
 
+/* ARGSUSED0 */
 AUpvlist _afQueryMiscellaneous (int arg1, int arg2, int arg3, int arg4)
 {
 	_af_error(AF_BAD_NOT_IMPLEMENTED, "not implemented yet");
 	return AU_NULL_PVLIST;
 }
 
+/* ARGSUSED2 */
 AUpvlist _afQueryMarker (int arg1, int arg2, int arg3, int arg4)
 {
 	switch (arg1)
 	{
 		case AF_QUERY_SUPPORTED:
 			return _af_pv_long(_af_units[arg2].markerCount != 0);
-			break;
 		case AF_QUERY_MAX_NUMBER:
 			return _af_pv_long(_af_units[arg2].markerCount);
-			break;
 		default:
 			_af_error(AF_BAD_QUERY, "bad query");
 			return AU_NULL_PVLIST;
-			break;
 	}
 
+	/* NOTREACHED */
 	return AU_NULL_PVLIST;
 }
 
+/* ARGSUSED0 */
 AUpvlist _afQueryCompression (int arg1, int arg2, int arg3, int arg4)
 {
 	_af_error(AF_BAD_NOT_IMPLEMENTED, "not implemented yet");
